polyPA: polyPA

Description Usage Arguments Value Key Reference Examples

View source: R/polyPA.R

Description

Conducts a parallel analysis using the method of Lubbe (2019). The code in this function is adapted from the key reference (see below). This function relies on the psych package to calculate the polychoric correlations.

Usage

1
polyPA(data, replications = 1000, prc = 0.99)

Arguments

data

Categorical input of questionnaire items

replications

The number of replications in the simulation

prc

The percentile for obtaining the reference eigenvalues

Value

Empirical and reference eigenvalues

Key Reference

https://doi.org/10.1037/met0000171

Examples

1
2
3
4
5
6
## Not run: 

pa_results <- polyPA(hl[1:10], 500, .99)


## End(Not run)

jameswgriffith/jamie documentation built on Dec. 20, 2021, 9:03 p.m.