Description Usage Arguments Value Key Reference Examples
Conducts a parallel analysis using the method of Lubbe (2019). The code in this function is adapted from the key reference (see below). This function relies on the psych package to calculate the polychoric correlations.
1 | polyPA(data, replications = 1000, prc = 0.99)
|
data |
Categorical input of questionnaire items |
replications |
The number of replications in the simulation |
prc |
The percentile for obtaining the reference eigenvalues |
Empirical and reference eigenvalues
https://doi.org/10.1037/met0000171
1 2 3 4 5 6 | ## Not run:
pa_results <- polyPA(hl[1:10], 500, .99)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.